@@ -30,16 +30,15 @@ class Store(StorageInterface):
     directory hierarchy implementation of a StorageInterface.
     """
 
-    def __init__(self, environ=None):
-        super(Store, self).__init__(environ)
+    def __init__(self, store_config=None, environ=None):
+        super(Store, self).__init__(store_config, environ)
         self.serializer = Serializer('text')
-        store_config = self.environ['tiddlyweb.config']['server_store'][1]
         self._root = self._fixup_root(store_config['store_root'])
         self._init_store()
 
     def _fixup_root(self, path):
         if not os.path.isabs(path):
-            path = os.path.join(self.environ['tiddlyweb.config']['root_dir'], path)
+            path = os.path.join(self.environ['tiddlyweb.config'].get('root_dir', ''), path)
         return path
 
     def _init_store(self):
